/*
 * Copyright (c) 2008 - 2020 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 * 
 * Licensed under the HARK license, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * https://www.hark.jp/notice/HARK_License_Agreement.pdf
 */

#if !defined(HARKMW_COLLECTOR_H_INCLUDED)
#define HARKMW_COLLECTOR_H_INCLUDED 1

#include <hark-base/BufferedNode.h>

namespace HARK
{
class HARKMW_Collector : public BufferedNode
{
public:
    HARKMW_Collector(const std::string &nodeName, const HARK::ParameterSet &params);

public:
    virtual void initialize();

    virtual ObjectRef getOutput(int output_id, int count);

    virtual ObjectRef getOutputNamed (const std::string &outputName, int count);

    virtual bool hasOutput(int output_id) const;

    virtual void request(int outputID, const ParameterSet &req);

    virtual void requestAll(const ParameterSet &req);

    virtual void calculate(int output_id, int count, Buffer &buf);

    ObjectRef getOutput(int outputID, int input_count, int output_count);
    ObjectRef getOutputNamed(const std::string &outputName, int input_count, int output_count);

protected:
    virtual int translateInput(const std::string &inputName);
    virtual int translateOutput(const std::string &inputName);

private:
    int last_input_count;
    int last_output_count;
    std::map<int, int> out2inMap;

};
}

#endif

/* end of file */
