/* -*- mode: C++; coding: utf-8 -*- */

/*
 * Copyright (c) 2013 - 2020 Honda Research Institute Japan Co., Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 * 
 * Licensed under the HARK license, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * https://www.hark.jp/notice/HARK_License_Agreement.pdf
 */

#ifndef LIBHARKMW__LIBHARMKW_H__INCLUDED
#define LIBHARKMW__LIBHARMKW_H__INCLUDED 1

#include <pybind11/pybind11.h>
#include <pybind11/complex.h>
#include <pybind11/numpy.h>
#include <pybind11/stl.h>
namespace py = pybind11;

#include <hark-base/BaseException.h>

#include <typeinfo>
#include <exception>

#define TRY_HARK(code, process) \
    try{ \
        code; \
    }catch(HARK::BaseException *ex){ \
        std::stringstream ss; \
        ss << "Exception thrown during " << (process); \
        throw HARKMW::hark_exception(ss.str(), ex); \
    } \

namespace HARKMW
{
class node_not_implemented : public std::runtime_error
{
public:
    using std::runtime_error::runtime_error;
};

class hark_exception : public std::runtime_error
{
protected:
    std::string message;
public:
    hark_exception(const std::string &message, HARK::BaseException *base_exception);
    virtual const char* what() const noexcept;
};
}

#endif
